==> nextcloud-app-news-1%3A25.2.0-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/is.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Beiðni mistókst, engin nettenging tiltæk!",
    "Request unauthorized. Are you logged in?" : "Beiðni ekki heimiluð. Ertu skráð/ur inn?",
    "Token expired or app not enabled! Reload the page!" : "Kenniteikn er útrunnið eða forrit ekki virkt! Þú ættir að hlaða síðunni aftur inn!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Innri miðlaravilla! Athugaðu skrána data/nextcloud.log fyrir nánari upplýsingar!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Fyrirspurn brást, Nextcloud er núna í viðhaldsham.",
    "Unread articles" : "Ólesnar greinar",
    "News" : "Fréttir",
    "Shared with me" : "Deilt með mér",
    "An RSS/Atom feed reader" : "RSS/Atom streymislesari",
    "Download" : "Niðurhal",
    "Close" : "Loka",
    "Web address" : "Veffang",
    "No folder" : "Engin mappa",
    "Folder name" : "Nafn möppu",
    "Username" : "Notandanafn",
    "Password" : "Lykilorð",
    "Feed exists already!" : "Streymið er þegar til!",
    "New folder" : "Ný mappa",
    "Folder exists already!" : "Mappan er þegar til!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Basic Auth auðkenni verða að geymast ódulrituð! Hver sá sem hefur aðgang að þjóninum eða gagnagrunninum mun hafa aðgang að þeim!",
    "Credentials" : "Auðkenni",
    "Subscribe" : "Áskrift",
    "Last job ran {relativeTime}." : "Síðasta verk var keyrt {relativeTime}.",
    "Maximum read count per feed" : "Hámarkfjöldi lestra á hvert streymi",
    "Maximum redirects" : "Hámarks endurbeiningar",
    "Feed fetcher timeout" : "Tímamörk streymissugu",
    "Explore Service URL" : "Skoða slóð á þjónustu (URL)",
    "Update interval" : "Uppfærslutíðni",
    "Use system cron for updates" : "Nota kerfis-cron fyrir uppfærslur",
    "How many redirects the feed fetcher should follow." : "Hversu mörgum endurbeiningum streymissugan á að fylgja.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Hámarksfjöldi sekúndna sem beðið er eftir að RSS eða Atom-streymi hlaðist inn; ef það tekur lengri tíma er hætt við uppfærslu.",
    "Interval in seconds in which the feeds will be updated." : "Tími í sekúndum sem líður milli þess sem streymi eru uppfærð.",
    "Move" : "Færa",
    "Share" : "Deila",
    "Share with" : "Deila með",
    "Mark read" : "Merkja sem lesið",
    "All articles" : "Allar greinar",
    "Starred" : "Stjörnumerkt",
    "Explore" : "Skoða",
    "Settings" : "Stillingar",
    "Keyboard shortcuts" : "Flýtilyklar",
    "Disable mark read through scrolling" : "Gera óvirkt að merkja sem lesið við skrun",
    "Show all articles" : "Birta allar greinar",
    "Reverse ordering (oldest on top)" : "Öfug röðun (elsta efst)",
    "Vertical" : "Lóðrétt",
    "Horizontal" : "Lárétt",
    "Rename" : "Endurnefna",
    "Delete" : "Eyða",
    "Rename Feed" : "Endurnefna streymi",
    "Unpin from top" : "Aftengja frá topphluta",
    "Pin to top" : "Tengja á topphluta",
    "Newest first" : "Nýjast fyrst",
    "Oldest first" : "Elsta fyrst",
    "Default order" : "Sjálfgefin röðun",
    "Enable full text" : "Virkja allan texta",
    "Disable full text" : "Afvirkja allan texta",
    "Unread updated" : "Ólesið uppfært",
    "Ignore updated" : "Hunsa uppfært",
    "Toggle star article" : "Víxla stjörnumerkingu af/á grein",
    "Mark unread" : "Merkja sem ólesið",
    "Close details" : "Loka nánari upplýsingum",
    "by" : "eftir",
    "from" : "frá",
    "Play audio" : "Spila hljóð",
    "Download audio" : "Sækja hljóð",
    "Download video" : "Sækja myndskeið",
    "Open website" : "Opna vefsvæði",
    "Keep article unread" : "Halda greininni sem ólesinni",
    "Toggle keep current article unread" : "Víxla af/á að halda greininni sem ólesinni",
    "Remove keep article unread" : "Fjarlægja að halda greininni sem ólesinni",
    "Keyboard shortcut" : "Flýtilykill",
    "Action" : "Aðgerð",
    "Jump to next article" : "Hoppa á næstu grein",
    "Jump to previous article" : "Hoppa á fyrri grein",
    "right" : "hægri",
    "left" : "vinstri",
    "Star article and jump to next one" : "Stjörnumerkja grein og hoppa í næstu",
    "Open article in new tab" : "Opna grein í nýjum flipa",
    "Refresh" : "Endurlesa",
    "Load next feed" : "Hlaða inn næsta streymi",
    "Load previous feed" : "Hlaða inn fyrra streymi",
    "Load previous folder" : "Hlaða inn fyrri möppu",
    "Load next folder" : "Hlaða inn næstu möppu",
    "Scroll to active navigation entry" : "Skruna á virka færslu í flakki",
    "Shift" : "Shift",
    "Subscribe to" : "Gerast áskrifandi að",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax eða webcron fannst! Fréttastraumar þínir verða ekki uppfærðir!",
    "How to set up the operating system cron" : "Hvernig á að setja upp cron-þjónustu stýrikerfis",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Setja upp og stilla hraðvirkari samhliða uppfærslueiningu sem notar API-forritsviðmót fréttaforritsins",
    "No articles available" : "Engar greinar tiltækar",
    "No unread articles available" : "Engar ólesnar greinar tiltækar",
    "Star article" : "Stjörnumerkja grein",
    "Unstar article" : "Taka stjörnugjöf af grein",
    "Description" : "Lýsing",
    "Toggle expand article in compact view" : "Víxla útflettingu greinar af/á í þjappaðri sýn",
    "Mark current article's feed/folder read" : "Merkja streymi/möppu núverandi greinar sem lesið",
    "Folder" : "Mappa",
    "Go back" : "Til baka",
    "New Folder" : "Ný mappa",
    "Create" : "Búa til",
    "Update failed more than 50 times" : "Uppfærsla mistókst oftar en 50 sinnum",
    "Deleted feed" : "Eyða streymi",
    "Undo delete feed" : "Afturkalla eyðingu á streymi",
    "Menu" : "Valmynd",
    "Open feed URL" : "Opna URL-slóð streymis",
    "Dismiss" : "Hafna",
    "Collapse" : "Fella saman",
    "Deleted folder" : "Eydd mappa",
    "Undo delete folder" : "Afturkalla eyðingu á möppu",
    "Compact view" : "Þjöppuð sýn",
    "Expand articles on key navigation" : "Virkja útflettingu greina við flakk með lyklaborði",
    "Subscriptions (OPML)" : "Áskriftir (OPML)",
    "Import" : "Flytja inn",
    "Export" : "Flytja út",
    "Error when importing: File does not contain valid OPML" : "Villa við innflutning: skrá inniheldur ekki gilt OPML",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Villa við innflutning: OPML inniheldur hvorki fréttastrauma né möppur",
    "Unread/Starred Articles" : "Ólesnar/stjörnumerktar greinar",
    "Error when importing: file does not contain valid JSON" : "Villa við innflutning: skrá inniheldur ekki gilt JSON",
    "Help" : "Hjálp",
    "Documentation" : "Hjálparskjöl",
    "Report a bug" : "Tilkynna um villu"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-app-news-1%3A26.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/is.js <==
OC.L10N.register(
    "news",
    {
    "Unread articles" : "Ólesnar greinar",
    "News" : "Fréttir",
    "Shared with me" : "Deilt með mér",
    "An RSS/Atom feed reader" : "RSS/Atom streymislesari",
    "Download" : "Niðurhal",
    "Close" : "Loka",
    "Web address" : "Veffang",
    "No folder" : "Engin mappa",
    "Folder name" : "Nafn möppu",
    "Username" : "Notandanafn",
    "Password" : "Lykilorð",
    "Feed exists already!" : "Streymið er þegar til!",
    "New folder" : "Ný mappa",
    "Folder exists already!" : "Mappan er þegar til!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Basic Auth auðkenni verða að geymast ódulrituð! Hver sá sem hefur aðgang að þjóninum eða gagnagrunninum mun hafa aðgang að þeim!",
    "Credentials" : "Auðkenni",
    "Subscribe" : "Áskrift",
    "Last job ran {relativeTime}." : "Síðasta verk var keyrt {relativeTime}.",
    "Maximum read count per feed" : "Hámarkfjöldi lestra á hvert streymi",
    "Maximum redirects" : "Hámarks endurbeiningar",
    "Feed fetcher timeout" : "Tímamörk streymissugu",
    "Explore Service URL" : "Skoða slóð á þjónustu (URL)",
    "Update interval" : "Uppfærslutíðni",
    "Use system cron for updates" : "Nota kerfis-cron fyrir uppfærslur",
    "How many redirects the feed fetcher should follow." : "Hversu mörgum endurbeiningum streymissugan á að fylgja.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Hámarksfjöldi sekúndna sem beðið er eftir að RSS eða Atom-streymi hlaðist inn; ef það tekur lengri tíma er hætt við uppfærslu.",
    "Interval in seconds in which the feeds will be updated." : "Tími í sekúndum sem líður milli þess sem streymi eru uppfærð.",
    "Move" : "Færa",
    "Share" : "Deila",
    "Share with" : "Deila með",
    "Default" : "Sjálfgefið",
    "Vertical" : "Lóðrétt",
    "Horizontal" : "Lárétt",
    "Mark read" : "Merkja sem lesið",
    "All articles" : "Allar greinar",
    "Starred" : "Stjörnumerkt",
    "Explore" : "Skoða",
    "Settings" : "Stillingar",
    "Documentation" : "Hjálparskjöl",
    "Keyboard shortcuts" : "Flýtilyklar",
    "Disable mark read through scrolling" : "Gera óvirkt að merkja sem lesið við skrun",
    "Show all articles" : "Birta allar greinar",
    "Reverse ordering (oldest on top)" : "Öfug röðun (elsta efst)",
    "Rename" : "Endurnefna",
    "Delete" : "Eyða",
    "Rename Feed" : "Endurnefna streymi",
    "Unpin from top" : "Aftengja frá topphluta",
    "Pin to top" : "Tengja á topphluta",
    "Newest first" : "Nýjast fyrst",
    "Oldest first" : "Elsta fyrst",
    "Default order" : "Sjálfgefin röðun",
    "Enable full text" : "Virkja allan texta",
    "Disable full text" : "Afvirkja allan texta",
    "Previous" : "Fyrra",
    "Next" : "Næst",
    "Toggle star article" : "Víxla stjörnumerkingu af/á grein",
    "Mark unread" : "Merkja sem ólesið",
    "Close details" : "Loka nánari upplýsingum",
    "by" : "eftir",
    "Play audio" : "Spila hljóð",
    "Download audio" : "Sækja hljóð",
    "Download video" : "Sækja myndskeið",
    "Open website" : "Opna vefsvæði",
    "Keep article unread" : "Halda greininni sem ólesinni",
    "Toggle keep current article unread" : "Víxla af/á að halda greininni sem ólesinni",
    "Remove keep article unread" : "Fjarlægja að halda greininni sem ólesinni",
    "Please wait" : "Bíddu aðeins",
    "Keyboard shortcut" : "Flýtilykill",
    "Action" : "Aðgerð",
    "Jump to next article" : "Hoppa á næstu grein",
    "Jump to previous article" : "Hoppa á fyrri grein",
    "right" : "hægri",
    "left" : "vinstri",
    "Star article and jump to next one" : "Stjörnumerkja grein og hoppa í næstu",
    "Open article in new tab" : "Opna grein í nýjum flipa",
    "Refresh" : "Endurlesa",
    "Load next feed" : "Hlaða inn næsta streymi",
    "Load previous feed" : "Hlaða inn fyrra streymi",
    "Load previous folder" : "Hlaða inn fyrri möppu",
    "Load next folder" : "Hlaða inn næstu möppu",
    "Scroll to active navigation entry" : "Skruna á virka færslu í flakki",
    "Shift" : "Shift",
    "Subscribe to" : "Gerast áskrifandi að",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax eða webcron fannst! Fréttastraumar þínir verða ekki uppfærðir!",
    "How to set up the operating system cron" : "Hvernig á að setja upp cron-þjónustu stýrikerfis",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Setja upp og stilla hraðvirkari samhliða uppfærslueiningu sem notar API-forritsviðmót fréttaforritsins"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
